@@ -27,7 +27,7 @@ class CoreVectorizer(Vectorizer):
 
     def vectorize(self, sample: WeatherForecast) -> List[float]:
         vectorized = [self._scale(sample.time_utc.month, 12),
-                      self._scale(sample.time_utc.hour, 24),
+                      self._scale(12-abs(12-sample.time_utc.hour), 12),
                       self._scale(sample.irradiance, 1000)]
         return vectorized
 
@@ -127,11 +127,6 @@ class FullVectorizer(CoreVectorizer):
         return "FullVectorizer"
 
 
-@dataclass(frozen=True)
-class TrainReport:
-    samples: List[LabelledWeatherForecast]
-
-
 class Estimator(ABC):
 
     @property
@@ -144,7 +139,11 @@ class Estimator(ABC):
         pass
 
     @abstractmethod
-    def retrain(self, train_data: TrainData) -> TrainReport:
+    def num_samples_last_train(self) -> int:
+        pass
+
+    @abstractmethod
+    def retrain(self, train_data: TrainData):
         pass
 
     @abstractmethod
@@ -168,7 +167,10 @@ class SVMEstimator(Estimator):
     def date_last_train(self) -> datetime:
         return self.__date_last_train
 
-    def retrain(self, train_data: TrainData) -> TrainReport:
+    def num_samples_last_train(self) -> int:
+        return self.__num_samples_last_train
+
+    def retrain(self, train_data: TrainData):
         samples = train_data.samples
         feature_vector_list = [self.__vectorizer.vectorize(sample) for sample in samples]
         label_list = [sample.power_watt for sample in samples]
@@ -180,7 +182,6 @@ class SVMEstimator(Estimator):
             logging.debug("estimator has been trained " + str(self))
         else:
             logging.debug("estimator can not be trained. Insufficient train data")
-        return TrainReport(samples)
 
     def predict(self, sample: WeatherForecast) -> int:
         if sample.irradiance > 0:   # shortcut. no irradiance means no power
