@@ -141,7 +141,6 @@ class TrainSampleLog:
             with gzip.open(compr_fn, "ab") as file:
                 line = sample.to_csv() + "\n"
                 file.write(line.encode(encoding='UTF-8'))
-            logging.info("train record appended " + str(sample))
 
         if datetime.now() > (self.__last_compaction_time + timedelta(days=self.COMPACTION_PERIOD_DAYS)):
             self.__last_compaction_time = datetime.now()
@@ -170,7 +169,7 @@ class TrainSampleLog:
 
         fn = self.filename()
         train_data = self.all()
-        min_datetime = datetime.now() - timedelta(days=400)
+        min_datetime = datetime.now() - timedelta(days=4*365)
 
         with tempfile.TemporaryDirectory() as tmp_dir:
             temp_file = os.path.join(tmp_dir, 'traindata.csv')
